@@ -30,7 +30,6 @@
 
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkx.h>
-#include <libgnomeui/gnome-help.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
 #define PLUGINS_CAPPLET_EXECUTABLE "gkbd-indicator-plugins-capplet"
@@ -215,9 +214,10 @@ GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 
 	switch (resp) {
 	case GTK_RESPONSE_HELP:
-		gnome_help_display_on_screen ("gswitchit", "layout-view",
-					      gtk_widget_get_screen
-					      (dialog), NULL);
+		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+			"ghelp:gswitchit?layout-view",
+			gtk_get_current_event_time (),
+			NULL);
 		return;
 	case GTK_RESPONSE_CLOSE:
 		gtk_window_get_position (GTK_WINDOW (dialog), &rect.x,
@@ -245,7 +245,7 @@ static void
 GSwitchItPreviewDestroy (GtkWidget * dialog, gint group)
 {
 	GtkBuilder *builder =
-	    GTK_BUILDER (gtk_object_get_data
+	    GTK_BUILDER (g_object_get_data
 			 (GTK_OBJECT (dialog), "builderData"));
 	g_object_unref (G_OBJECT (builder));
 	g_hash_table_remove (globals.previewDialogs,
@@ -364,7 +364,7 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	}
 	g_object_unref (G_OBJECT (xklData));
 
-	gtk_object_set_data (GTK_OBJECT (dialog), "builderData", builder);
+	g_object_set_data (GTK_OBJECT (dialog), "builderData", builder);
 	g_signal_connect (GTK_OBJECT (dialog),
 			  "destroy", G_CALLBACK (GSwitchItPreviewDestroy),
 			  GINT_TO_POINTER (xklState->group));
@@ -386,7 +386,7 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 			   (gtk_builder_get_object
 			    (builder, "preview_vbox")), kbdraw);
 
-	gtk_object_set_data (GTK_OBJECT (dialog), "kbdraw", kbdraw);
+	g_object_set_data (GTK_OBJECT (dialog), "kbdraw", kbdraw);
 
 	g_hash_table_insert (globals.previewDialogs,
 			     GINT_TO_POINTER (xklState->group), dialog);
@@ -447,9 +447,10 @@ void
 GSwitchItAppletCmdHelp (BonoboUIComponent
 			* uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	gnome_help_display_on_screen ("gswitchit", NULL,
-				      gtk_widget_get_screen (sia->applet),
-				      NULL);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (sia->applet)),
+		"ghelp:gswitchit-view",
+		gtk_get_current_event_time (),
+		NULL);
 } void
 GSwitchItAppletCmdAbout (BonoboUIComponent *
 			 uic, GSwitchItApplet * sia, const gchar * verb)
@@ -664,7 +665,7 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	g_signal_connect (GTK_OBJECT (sia->gki), "reinit-ui",
 			  G_CALLBACK (GSwitchItAppletReinitUi), sia);
 
-	gtk_object_set_data (GTK_OBJECT (sia->applet), "sia", sia);
+	g_object_set_data (GTK_OBJECT (sia->applet), "sia", sia);
 	GSwitchItAppletSetupMenu (sia);
 	return TRUE;
 }
